@@ -1,12 +1,12 @@
 package Parse::PhoneNumber::ID;
 
-our $DATE = '2015-01-04'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Function::Fallback::CoreOrPP qw(clone);
 use Perinci::Sub::Util qw(gen_modified_sub);
@@ -983,7 +983,7 @@ Parse::PhoneNumber::ID - Parse Indonesian phone numbers
 
 =head1 VERSION
 
-This document describes version 0.13 of Parse::PhoneNumber::ID (from Perl distribution Parse-PhoneNumber-ID), released on 2015-01-04.
+This document describes version 0.14 of Parse::PhoneNumber::ID (from Perl distribution Parse-PhoneNumber-ID), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -1018,13 +1018,18 @@ To extract more than one numbers in a text:
  say "There are ", scalar(@$phones), "phone number(s) found in text";
  for (@$phones) { say $_->{pretty} }
 
+=head1 SEE ALSO
+
+L<Parse::PhoneNumber>
+
 =head1 FUNCTIONS
 
 
 =head2 extract_id_phones(%args) -> any
 
-Extract phone number(s) from text.
+{en_US Extract phone number(s) from text}.
 
+{en_US 
 Extracts phone number(s) from text. Return an array of one or more parsed phone
 number structure (a hash). Understands the list of known area codes and cellular
 operators, as well as other information. Understands various syntax e.g.
@@ -1036,6 +1041,7 @@ Indonesian language, but should be quite suitable for any other normal text.
 
 Non-Indonesian phone numbers (e.g. +65 12 3456 7890) will still be extracted,
 but without any other detailed information other than country code.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1043,35 +1049,41 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_area_code> => I<str>
 
-When encountering a number without area code, use this.
+{en_US When encountering a number without area code, use this}.
 
+{en_US 
 If you want to extract numbers that doesn't contain area code (e.g. 7123 4567),
 you'll need to provide this.
+}
 
 =item * B<level> => I<int> (default: 5)
 
-How hard should the function extract numbers (1-9).
+{en_US How hard should the function extract numbers (1-9)}.
 
+{en_US 
 The higher the level, the harder this function will try finding phone numbers,
 but the higher the risk of false positives will be. E.g. in text
 '123456789012345' with level=5 it will not find a phone number, but with level=9
 it might assume, e.g. 1234567890 to be a phone number. Normally leaving level at
 default level is fine.
+}
 
 =item * B<max_numbers> => I<int>
 
 =item * B<text>* => I<str>
 
-Text containing phone numbers to extract from.
+{en_US Text containing phone numbers to extract from}.
 
 =back
 
 Return value:  (any)
 
+
 =head2 parse_id_phone(%args) -> any
 
-Alias for extract_id_phones(..., max_numbers=>1)->[0].
+{en_US Alias for extract_id_phones(..., max_numbers=>1)->[0]}.
 
+{en_US 
 Extracts phone number(s) from text. Return an array of one or more parsed phone
 number structure (a hash). Understands the list of known area codes and cellular
 operators, as well as other information. Understands various syntax e.g.
@@ -1083,6 +1095,7 @@ Indonesian language, but should be quite suitable for any other normal text.
 
 Non-Indonesian phone numbers (e.g. +65 12 3456 7890) will still be extracted,
 but without any other detailed information other than country code.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -1090,31 +1103,32 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_area_code> => I<str>
 
-When encountering a number without area code, use this.
+{en_US When encountering a number without area code, use this}.
 
+{en_US 
 If you want to extract numbers that doesn't contain area code (e.g. 7123 4567),
 you'll need to provide this.
+}
 
 =item * B<level> => I<int> (default: 5)
 
-How hard should the function extract numbers (1-9).
+{en_US How hard should the function extract numbers (1-9)}.
 
+{en_US 
 The higher the level, the harder this function will try finding phone numbers,
 but the higher the risk of false positives will be. E.g. in text
 '123456789012345' with level=5 it will not find a phone number, but with level=9
 it might assume, e.g. 1234567890 to be a phone number. Normally leaving level at
 default level is fine.
+}
 
 =item * B<text>* => I<str>
 
-Text containing phone numbers to extract from.
+{en_US Text containing phone numbers to extract from}.
 
 =back
 
 Return value:  (any)
-=head1 SEE ALSO
-
-L<Parse::PhoneNumber>
 
 =head1 HOMEPAGE
 
@@ -1122,7 +1136,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Parse-Phon
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Parse-PhoneNumber-ID>.
+Source repository is at L<https://github.com/perlancar/perl-Parse-PhoneNumber-ID>.
 
 =head1 BUGS
 
